
import { H4, H5 } from "../components/Headings";
import { LoremMedium } from "../components/Loremipsum";
import { SupScrollLink } from "../components/ScrollLink"; 
import { Section, Subesction } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";



export const Safety: React.FC = () =>{
  useTabNavigation();
  
  return (
    <>
      <Section title="Role in iGEM" id="Role">
        <LoremMedium/>
      </Section>
      <Section title="Check-Ins" id="Check-Ins">
        <div>
            <p>
            As part of our project to develop a prime-editing complex to correct the F508del mutation in cystic fibrosis, we place great emphasis on safety at all stages of research. Our final construct will be tested in primary cultures of epithelial cells obtained from nasal swabs, isolated from both patients and healthy individuals. from nasal swabs [link primär Kulturen]. To guarantee safety and ensure the highest level of precision and reliability of our results, we have introduced a series of carefully planned checkpoints during the experiments. These milestones allow for continuous monitoring, timely adjustments and validation at each critical stage. This ensures that potential issues are identified and addressed immediately, minimizing risk and improving the overall quality of the experimental results. [link zu den Experimenten] . iGEM places great emphasis on biosafety, ensuring that all projects adhere to strict safety standards. One of these measures is the iGEM White List, which includes organisms and parts that are pre-approved for use based on their safety profile. Any components or organisms not covered by this White List must be submitted as 'Check-ins' to the iGEM Safety Committee for approval. Check-ins are formal safety evaluations that allow the committee to assess the potential risks and ensure proper containment and handling procedures are in place. Although we used some parts and organisms that were not included on the White List, these were assessed as critical for our project and submitted as Check-ins to the iGEM Safety Committee. Furthermore, we were in active exchange with the committee throughout the process. The Check-ins provide a clear picture of the biosafety aspects of our project, reflecting our commitment to safety and compliance with iGEM standards. 
            The main safety measures we have implemented include:
            </p> 
            <p>
            <strong>Compliance with S1 conditions:</strong> Working in S1 laboratories ensures that only organisms in the lowest risk group are used, minimizing the risk to humans and the environment. 
            </p>
            <p>
            <strong>Sterile working practices:</strong> To avoid contamination, we have implemented strict hygiene measures, including the disinfection of work surfaces and the correct disposal of biological waste. 
            </p>
            <p>
            <strong>Controlled access:</strong> Access to laboratories was strictly regulated to ensure that only trained personnel worked with the genetically modified organisms and cell lines. 
            </p>
            <p>
            <strong>Documentation:</strong> All work steps, materials used and cell lines were carefully documented to ensure traceability and safety. 
            </p>
            <p>
            <strong>Safe handling of cell lines:</strong> The cell lines used for experiments were handled in accordance with the applicable safety regulations. This included regular checks for contamination and the safe storage and disposal of cell cultures. 
            </p>
            <H4 text="Check-in for the Prime-Editing Komplex "></H4>
            <p>
            <strong>Reverse transcriptase:</strong> Reverse transcriptase plays a central role in prime editing by specifically inserting the correction as DNA at the inserted nick using an RNA template provided by pegRNA. The correction of the complementary DNA strand then takes place via the natural cell repair mechanisms.  This ensures an exact correction of the target sequence. We checked the reverse transcriptase to ensure it could perform precise genome editing without introducing unintended mutations. This was important to minimize the risk of off-target effects that could lead to unexpected or harmful consequences.
            </p>
            <p>
            <strong>pegRNA (Prime Editing Guide RNA):</strong> The pegRNA is a multifunctional RNA molecule that fulfils two essential tasks. Firstly, it serves as a standard guide RNA (gRNA) that binds specifically to the target DNA and thus marks the site of editing. Secondly, it contains an RNA template that encodes the desired DNA modification. This enables the precise integration of the genetic modifications at the target site. We evaluated pegRNA for its ability to specifically target and modified the intended DNA sequence. Ensuring its specificity was crucial to avoid the potential disruption of other genes.
            </p>
            <p>
            <strong>Nickase Cas9, CasX, Fanzor (SpuFz1):</strong> These modified nucleases are designed to cut only one strand of DNA. This leads to controlled and precise editing of the genome, as cutting only one strand minimizes the risk of unwanted double-strand breaks. CasX and Fanzor offer smaller alternatives to Cas9, which is particularly advantageous for use in cells or organisms where space and efficiency requirements in terms of the transport system are an issue. Fanzor, being a newly introduced endonuclease, was particularly scrutinized in our project to ensure its safety and effectiveness in different cellular contexts. 
            
            This prime-editing complex thus represents a precise and efficient method for gene editing. By combining these components, genetic modifications can be performed with minimal side effects
            </p>
            <H4 text="Check-in for Cloning"></H4>
            <p>
            For our  cloning experiments and the development of our prime editing complexes, we have amplified various plasmids in <i>E. coli</i> K-12 strains (DH5α,10-Beta) When working with microbial strains such as <i>E. coli</i> K-12 strains,  a it's important to consider potential risks associated with their use, even though they are generally regarded as safe in laboratory settings. All experiments were performed under strict S1 conditions, following all relevant safety protocols. Below you will find an overview of the <i>E. coli</i> K-12 strains for our cloning experiments, submitted by us as a checkin and the specific safety measures:
            </p>
            <p>
            <strong><i>E. coli K-12</i> strains (DH5α,10-Beta):</strong> Although these strains are non-pathogenic and have been modified to minimize the risk of spreading antibiotic resistance, there remains a low risk of horizontal gene transfer, where genetic material could be transferred to other microorganisms, potentially leading to the spread of resistance genes or other traits. If accidentally released into the environment, <i>E. coli</i> K-12 strains could potentially interact with native microbial communities. While they are typically outcompeted in natural environments, there's a remote possibility of ecological disruption, particularly in microenvironments where they could find a niche.While these strains are non-virulent, they still pose a minimal risk to humans, particularly immunocompromised individuals, through accidental ingestion or inhalation in a laboratory setting. 
            </p>
            <p>
            We submitted  the yeast strain <i>Pichia pastoris</i> (SMD1163) for the protein expression of Fanzor.
            </p>
            <p>
            <strong><i>Pichia pastoris</i> (SMD1163):</strong> <i>Pichia pastoris</i> (SMD1163) is a widely used yeast strain for the expression of recombinant proteins. It is characterized by a methanol-inducible expression system (AOX1 promoter) and high cell growth rates, which makes it ideal for industrial applications. The strain can be easily genetically manipulated and can perform post-translational modifications, which supports correct protein production.
            When working with <i>Pichia pastoris</i> (SMD1163), various safety-relevant aspects must be observed. Although the organism is considered non-pathogenic and biologically safe (S1), skin contact and aerosol formation should be avoided to minimize the risk of infection or allergic reactions. When using genetically modified strains, it is important to follow the relevant GMO guidelines to prevent uncontrolled release. In addition, handling chemicals such as methanol requires special precautions as they are toxic and highly flammable. The disposal of cell cultures and waste must also be carried out in accordance with biosafety regulations, especially in the case of genetically modified organisms. 
            </p>
            <H4 text="Check-in for Testing in cell lines "></H4>
            <p>
            In our project, we paid attention to safety at every step, especially when working with specific cell lines [link Zellinien]. All experiments were performed under strict S1 conditions, following all relevant safety protocols. Given the sensitivity of the human cell lines we used, we placed great emphasis on controlled and well-designed workflows. All transfections were performed in our own transfection laboratory to ensure a high level of safety and compliance.  Below you will find an overview of the cell lines submitted by us as a checkin and the specific safety measures: 
            HEK293T-3HA-CFTR.
            The HEK293T-3HA-CFTR cell line is based on HEK293T cells expressing an additional tsA1609 allele of the SV40 large T antigen. This allele enables the replication of vectors containing the SV40 origin of replication. In addition to the native CFTR gene, which is not expressed in HEK cells, the HEK293T-3HA-CFTR cell line from Leuven carries another copy of the CFTR gene embedded in an expression cassette. This cassette contains a CMV promoter, which is derived from the human cytomegalovirus and is frequently used for the overexpression of genes in human cells. In addition, the cassette contains a puromycin resistance gene that is co-expressed with CFTR, allowing continuous selection of CFTR-expressing cells. 
            </p>
            <p>
            <strong>HEK293T-3HA-F508del-CFTR cell line:</strong> The HEK293T-3HA-F508del-CFTR cell line is a modified HEK293T cell line that carries the F508del mutation in the CFTR gene, which is responsible for the most common mutation in cystic fibrosis. This mutation leads to a defective CFTR protein that impairs the normal function of the chloride channel. The cell line is therefore ideal for studying the effects of this mutation and for evaluating potential therapies for cystic fibrosis. 
            </p>
            <p>
            <strong>CFBE41o- cell line:</strong> The CFBE41o- cell line, derived from the bronchial epithelial cells of a cystic fibrosis patient, is homozygous for the ΔF508-CFTR mutation and was essential for our cystic fibrosis research. A reduced CFTR expression level is present. The cell line carries the CFTR defect and can therefore represent a patient with CF. The cell line is used to test our mechanism. These cells were immortalized with a replication-defective plasmid that retains their physiological properties.
            When working with the HEK293T and CFBE41o- cell lines, it’s important to consider the minimal risks associated with their use. While not harmful on their own, the genetic modifications in HEK293T cells require careful handling to prevent accidental release or exposure. These cells, engineered to overexpress CFTR, including the F508del mutation, necessitate strict safety measures like regular monitoring and proper waste disposal to comply with S1 laboratory standards. Similarly, CFBE41o- cells, due to their genetic modifications and disease relevance, require careful handling to avoid cross-contamination and ensure biosafety.
            </p>
            <p>
            <strong>Human nasal epithelial cells (hNECs):</strong> Human nasal epithelial cells (hNECs) were harvested using a nasal brush, a minimally invasive procedure, and cultured in air-liquid interface (ALI) cultures to model the airway epithelium. Human nasal epithelial cells (hNECs) were obtained using a nasal brush, a minimally invasive technique, and then cultured in air-liquid interface (ALI) cultures to model the airway epithelium. Using these primary cultures, derived from donors with airway diseases such as cystic fibrosis, we were able to simulate the in vivo conditions of such diseases.  
            Due to the sensitive nature of these primary human cells, we performed all experiments with hNECs in our S2 laboratory, where increased safety precautions were taken. This included strict safety controls, safe handling of samples and proper disposal of materials after testing. In particular, the hNECs underwent HHH (Triple H: HIV, HCV and HBV) testing to ensure that no contamination occurred during sample collection or experimentation. These tests included sterility testing, viability assessments and contamination testing to ensure the safety and integrity of both the samples and the laboratory environment. After a negative HHH test, the primary cultures can be treated as S1. In addition, the nasal epithelial cells were handled with the utmost care during collection, ensuring that all procedures were performed under sterile conditions to avoid any risk of contaminationFor this purpose, the intensive examination of ethical questions was fundamental and a constant companion of our project. The numerous results from the interviews in the areas of: Ethics, storage and training in the handling of samples have been summarized in a guideline for patient consent for Germany and are intended to provide iGEM teams with the scope, critical examination and observance of iGEM rules, international and national guidelines.  
            </p> 
            <H4 text="Checkin for Delivery "></H4>
            <p>
            Our finished construct is designed to be delivered into the lung via an inhaler using lipid nanoparticles (LNPs). To be more spezific a selective organ-targeting (SORT)- LNPs were developed to deliver mRNA specifically to the lung, with special measures taken to increase biocompatibility and safety. Since the LNP composition is very specific and also differs from other formulas, we submitted the LNP as a checkin:
            </p>
            <p>
            <strong>LNP:</strong> These LNPs are then taken up by epithelial cells through endocytosis, releasing the construct into the cytosol. We carefully evaluated the potential risks, including unintended immune responses and the need for precise dosing to minimize side effects. In addition, we have conducted an in-depth analysis of the dual-use potential of our technology. Dual-use refers to the possibility that scientific advances can be used for both civilian and military purposes. Therefore, we have implemented strict safety protocols and ethical guidelines to ensure that our technology is used exclusively for peaceful and therapeutic applications. 
            </p>
        </div>
      </Section>
      <Section title="Our Lab" id="Our Lab">
        <p>
        As part of our laboratory activities for our PreCyse project, we worked in various laboratories. For general lab work and cloning experiments, you can find some pictures of our laboratories below:  
        </p>
        <H4 text="Our Cloning Lab"></H4>
        <p>
        Our Cloning-laboratory is divided into different work areas to ensure that the experiments run smoothly and efficiently. These include the gel station, the PCR station, the transformation section and the measurement area. Each area is specially equipped for the respective method, and the corresponding experiments were carried out exclusively in the designated stations. In this way, we ensure that our work is carried out under optimal conditions and with the greatest possible precision. 
        </p>
        <H4 text="Our Cell Culture Lab "></H4>
        <p>
        In our cell culture laboratory, we work under sterile conditions to ensure optimal growth conditions for human cell lines. Among other things, we carry out transfections in order to introduce genetic material into cells and investigate their behavior. Strict protocols and state-of-the-art technology ensure the precision and reproducibility of our experiments. 
        </p>
        <p>
        In our S2 laboratory, the harvested nasal epithelial cells that serve as primary cultures undergo a comprehensive HHH test (link zu primär Kulturen) to ensure their safety and suitability for further experiments. This test is crucial to ensure that we can subsequently work safely with these cells in the S1 range without the risk of contamination or unwanted release of biological material. 
        </p> 
      </Section>
      <Section title="Biosafety" id="Biosafety">
        <Subesction title="Mechanism" id="Biosafety1">
          <p>
          The biosafety of our Prime Editing complex has been a top priority throughout the entire development process. We have therefore tried to optimise all parts that influence the biosecurity of our system as much as possible. To ensure maximum biosecurity, we have created and tested many designs, as well as extensively researched alternatives and/or additional elements that contribute to biosecurity.
          </p>
          <H4 text="PAM disrupt" ></H4>
          <p>
          A key safety mechanism incorporated in our design of the Prime Editing complex is the disruption of the PAM sequence. For the nickase enzyme to function properly, it must bind directly to the DNA strand, a process that is facilitated by the presence of a specific sequence called the PAM (Protospacer Adjacent Motif). This critical interaction occurs through the recognition of the PAM sequence by the nickase itself. To achieve PAM disruption, the pegRNA (prime editing guide RNA) is specifically designed in a way so that the PAM sequence is situated within the reverse transcription template (RTT) of the pegRNA. By introducing a silent mutation within the RT template into the PAM sequence. Therefore the PAM sequence is effectively eliminated after the gene editing process is successfully completed [1]. As a result of that, the PAM sequence is no longer present on the DNA strand, preventing the nickase from binding again at the same location. This reduction in repeated or undesired binding of the nickase enhances the safety of our prime editing complex, minimizing the risk of unintended edits or off-target effects in subsequent steps. Ultimately, this feature contributes very much to the overall safety and reliability of the prime editing process.
          </p>
          <H4 text="pegRNA design - Spacer"></H4>
          <p>
          Biosafety is also guaranteed by the careful selection of the spacer, which plays a critical role in guiding the complex to its intended target site [2]. To ensure both precision and safety, we meticulously chose and rigorously checked the spacer using the CRISPick software [3]. This allowed us to evaluate whether our Spacer would be likely to target other regions than our target site and therefore allowing us to analyse and predict potential off-target effects, ensuring that erroneous edits are minimised. By optimising the spacer selection, we have not only significantly enhanced the overall editing efficiency, striking a balance between precision and performance, but especially ensured the utmost accuracy in directing the Prime Editor, further contributing to the safety of the editing process. [Bild 1]
          </p>
          <H4 text="Riboswitch"></H4>
          <p>
          Riboswitches are segments of an RNA strand that bind to small molecules, causing them to change their secondary structure by forming hairpin structures. This process regulates gene expression at the translation level by preventing ribosomes from binding at the RBS and translating the coding region on the RNA strand. 0For our project we also considered an ion-sensitive riboswitch, specifically dependent on sodium ions (Na⁺), as a regulatory mechanism. The secondary structure of this riboswitch prevents the binding of ribosomes to the ribosome binding site (RBS) under normal conditions, thus inhibiting the translation of the subsequent mRNA. When sodium ions bind to the riboswitch, a structural change occurs, exposing the RBS, which allows for the translation of the mRNA and the production of our fusion protein which is the main component of our prime editing system and therefore of enormous importance for it to work [4]. In the context of the CFTR mutation and its effects on the cell, the elevated Na⁺ levels play a crucial role. Due to the dysfunctional CFTR channel, which fails to properly function as a chloride channel, the ENaC channel (epithelial sodium channel) becomes upregulated. This upregulation results in an increased transport of sodium ions into the cell, leading to a higher intracellular sodium concentration. This elevated Na⁺ concentration creates a specific ionic environment that could potentially be utilized to regulate our Prime-Editing complex in a targeted manner. Given these specific ionic changes in the cell, we could have a disease-specific regulation of our Prime-Editing system based on the ionic situation typical of this condition. However, despite the initial promise of this approach, after further research, we concluded that the riboswitch, even considering the ion levels within epithelial cells, is overall too nonspecific and therefore too unreliable as a regulatory mechanism. Although the ion levels in CFTR cells are much lower, there are still low concentrations of sodium ions, which can lead to the riboswitch not being completely switched off.
          [Bild 2]
          As a further approach to developing alternative riboswitch variants, we considered the possibility of an RNA-regulated riboswitch targeting the defective mRNA sequence of the genetically defective CFTR gene. The basic idea behind this concept was that the riboswitch specifically binds to a region on the CFTR mRNA containing the F508Δ mutation. This binding should induce a structural change in the riboswitch on our prime editing complex’s mRNA that ultimately leads to exposure of the RBS to allow translation of the downstream sequence. This mechanism would be designed to react specifically to the defective CFTR mRNA and only cause a change in the secondary structure in the presence of the specific mutation. The riboswitch could thus ensure selective and disease-specific activation of our prime editing complex, which would be of particular interest in the context of genetic diseases such as cystic fibrosis. However, we did not pursue this approach any further. A major reason for this was the lack of sufficient literature providing a sound scientific basis for this specific application of a riboswitch. In
          addition, our research steered us in a different direction, particularly with regard to the alternative mechanism involving the XBP1 intron to regulate the prime editing system. This alternative seemed more promising and was based on an established regulatory mechanism that is triggered by cellular stress and specifically responds to misfolding processes.
          </p>
          <H4 text="XBP1 Intron"></H4>
          <p>
            After extensive research, we discovered a regulatory system in eukaryotic cells, the XBP1 mechanism. The activation of XBP1 is an important mechanism that occurs as part of the Unfolded Protein Response (UPR), a cellular stress response triggered by the accumulation of misfolded proteins in the endoplasmic reticulum (ER). The ER is a key cellular component responsible for protein folding and transport. When many misfolded proteins accumulate in the ER, a specific regulatory mechanism is activated to reduce the stress on the ER. XBP1 activation is controlled by a protein called IRE1α, which is embedded in the ER membrane. IRE1α acts as a sensor for protein misfolding stress in the ER. Once IRE1α detects misfolded proteins, it dimerizes and becomes activated through autophosphorylation. This activation switches on the endoribonuclease activity of IRE1α, which is a crucial step in the activation of XBP1. The mRNA for XBP1 is continuously transcribed in the nucleus and transported to the cytoplasm, where it contains an intron that is not normally spliced out. This intron contains a stop codon, preventing the translation of a functional XBP1 protein. However, when ER stress activates IRE1α, the endoribonuclease domain of IRE1α splices this intron out of the XBP1 mRNA. This is an unconventional splicing event, as it occurs in the cytoplasm rather than in the nucleus. Once the intron is removed, the spliced XBP1 mRNA can be translated into a functional XBP1 protein. This activated XBP1 acts as a transcription factor, turning on genes that increase the protein-folding capacity of the ER and promote the degradation of misfolded proteins. In this way, XBP1 helps the cell cope with ER stress and restore balance in the protein-folding process. Thus, this mechanism originally functions within the cell in the context of ER stress to maintain ER function when protein folding is disrupted. [5] [6] Our idea was therefore to integrate this intron into the mRNA encoding our prime-editing complex and thus use this mechanism to ensure that a functional prime editor is only synthesized when there is a high accumulation of misfolded proteins in the cell (similar to F508del). This would therefore represent an optimal safety aspect, as our fusion protein, which is essential for prime editing, cannot be fully synthesised as long as the genetic defect is not present in the cell. Accordingly, this provides the security that no healthy cells, as well as correctly edited cells, cannot be edited, which is an enormous contribution to biosafety. However, there was too much uncertainty about the extent to which other factors, such as misfolded proteins that are not associated with the CFTR protein, play a role in this mechanism. And since we could not and did not want to take the risk of such factors initiating the system, we decided against using it. To clarify this unknown correlation, we have considered a future experiment in which we want to switch this intron in front of a fluorescent marker and express it in cells with defective CFTR in order to confirm/investigate the dependence of intron splicing and the presence of CFTR F508del.
          </p>
        </Subesction>
        <Subesction title="Safety aspects of our Airbuddy" id="Biosafety2">
          <H4 text="SORT LNP and Cytotoxicity"></H4>
          <p>
          We have carefully considered the biosafety aspects of our delivery system, starting with the decision between Adeno-associated viruses (AAV) or lipid nanoparticles (LNPs) as delivery systems. Our comparison revealed that the biocompatibility and safety of LNPs are paramount for our approach. That is why we chose selective organ-targeting (SORT) lipid nanoparticles (LNPs) [1] in the context of targeted pulmonary mRNA delivery. One of our primary concerns with the LNP was the potential cytotoxicity of polyethylene glycol (PEG), a common stabilizing agent in LNP formulations. Aware of the immune responses PEG can trigger, potentially leading to cytotoxicity [2], we aimed at optimizing its concentration in our SORT LNPs to minimize such reactions while maintaining therapeutic efficacy. By the use of low molecular weight PEG, we addressed this problem. To test weather our approach succeeded, we conducted MTT and proliferation assays to ensure that our LNP posed no cytotoxicity risks.
          </p>
          <H4 text="Precision of our SORT LNP"></H4>
          <p>
          To further improve safety, we focused on reducing off-target effects. By incorporating specific SORT molecules, such as permanently cationic lipids like DOTAP, we ensured that the nanoparticles are systematically directed to the lungs. This precise targeting is particularly beneficial for respiratory diseases, as it enhances therapeutic effectiveness while limiting the impact on non-target organs. Our outlook of antibody conjugation as surface modification of our LNP for cell type-specific delivery, more exactly club cells [3] and ionocytes [4] as CFTR-expressing lung epithelial cells, would round off this aspect.
          </p>
          <p>
          In summary, our design strategy emphasizes both safety and efficacy. The careful optimization of components like PEG 2000 and the use of targeted delivery molecules allow SORT LNPs to deliver therapeutic agents directly to the lungs, reducing systemic exposure and minimizing side effects. This targeted approach ensures more effective treatments, especially for conditions requiring localized intervention.
          </p>
        </Subesction>
      </Section>
      <Section title="Biosecurity" id="Biosecurity">
        <Subesction title="About Our Project" id="Biosecurity1">
          <p>
          Our project focuses on the genetic disease cystic fibrosis, specifically targeting the Delta-508 mutation. The aim is to correct this mutation using Prime Editing, a precise genome-editing technique. We have explored different strategies to optimize the Prime Editing complex for this specific application. 
          </p>
          <p>
          The Prime Editing complex consists of a nickase, a reverse transcriptase, a pegRNA. The pegRNA guides the editing process by directing the complex to the target DNA sequence, allowing for precise genetic modifications. For targeted delivery, we selected lipid nanoparticles (LNPs) to introduce the mRNA encoding the Prime Editing components specifically into lung epithelial cells, where the CFTR protein is highly expressed. Additionally, we investigated alternatives to the conventional Cas9 nickase, such as the smaller CasX and Fanzor, aiming to reduce the overall size of the Prime Editing complex. In our optimization efforts, we also explored smaller reverse transcriptases to enhance the efficiency of the system in human cells. 
          </p>
          <p>
          Furthermore, we have developed a modular plasmid that contains the backbone of our Prime Editing complex. The individual components can be cloned individually into the backbone. This plasmid allows us to either deliver the construct directly into target cells or transcribe the plasmid into RNA, enabling the delivery of the Prime Editing complex in the form of mRNA. The modularity of the plasmid is a key feature; specific restriction sites are included to facilitate the easy exchange of the complex's components. This design makes it straightforward to adapt the Prime Editing complex for various use cases and therapeutic requirements. 
          </p>
          <p>
          We have investigated safety mechanisms to control the prime-editing complex, including a riboswitch that responds to sodium ion concentrations, but have discarded it due to suspected insufficient sensitivity. We are currently investigating the use of the ER stress response to activate the prime editing complex only in cells with high ER stress, as is typical for cystic fibrosis. Further details can be found in the Biosafety section. 
          </p>
        </Subesction>
        <Subesction title="Assesing Project Risks" id="Biosecurity2">
          <p>
          Given the sensitive nature of genome editing, our project presents specific biosecurity concerns that need to be assessed and mitigated. 
          </p>
          <p>
            <strong>Dual-Use Potential:</strong> One of the main biosecurity risks is the potential for dual-use of the Prime Editing technology. The system we are developing, while intended for therapeutic use, could be misused to target other genes or genomes for malicious purposes.1 This includes the possibility of weaponizing the technology to induce harmful genetic changes in crops, animals, or even humans. The modular design of our plasmid system, although intended to facilitate optimization, could be exploited to exchange components for harmful applications, thereby increasing the risk of misuse. 
          </p>
          <p>
            <strong>Unintendend Dissemination:</strong> Since our approach uses mRNA delivered via LNPs, there is a risk of unintended dissemination into the environment. If the LNPs are not adequately contained or disposed of, there is a possibility that they could be absorbed by non-target organisms, potentially leading to off-target genetic modifications.2 In addition, the mRNA itself could theoretically be transferred between cells, especially if taken up by unintended hosts, raising concerns about unintentional spread in the environment. 
          </p>
          <p>
            <strong>Unauthorized Access:</strong> The genetic constructs and the detailed methodology of our Prime Editing system must be securely stored and protected.3 If unauthorized individuals were to gain access to the plasmids, LNP formulations, or editing protocols, there is a risk of the technology being replicated or adapted for unintended, potentially harmful uses. This highlights the importance of proper biosecurity protocols in both physical and digital storage of our project materials. 
          </p>
          <p>
            <strong>Synthetic Biology and information Sharing:</strong> The ease of synthesizing genetic material means that our project information could potentially be used to order similar constructs from commercial synthesis providers.4 While these providers follow biosecurity guidelines, the increasing accessibility of synthetic biology raises the concern of our Prime Editing system being reproduced or modified without our knowledge. This includes potential attempts to bypass safety mechanisms or create variants that evade current regulatory frameworks. 
          </p>
          <p>
            <strong>Public Perception and Miscommunication:</strong> There is a biosecurity risk in how our project's technology is communicated to the public.5 Miscommunication or misunderstanding of the project’s intent and capabilities could lead to misinformation, fear, or even attempts to replicate the technology outside of controlled and regulated environments. This could undermine public trust in legitimate therapeutic uses of genome-editing technologies and potentially facilitate misuse.  
          </p>
        </Subesction>
        <Subesction title="Managing Risks" id="Biosecurity3">
          <H5 text="Dual-Use Potential"></H5>
          <p>
          To mitigate the risk of dual-use, where our Prime Editing technology could be exploited for unintended and potentially harmful purposes, we have implemented several strategies. 
          </p>
          <p>
          Firstly, we strictly control access to all our project data, including genetic sequences, plasmid designs, and protocols. Access is limited to authorized team members and collaborators who follow strict biosecurity guidelines. Further elaboration on these access controls will be provided in the "Unauthorized Access" section.
          </p>
          <p>
          Secondly, we intend to incorporate a safety mechanism into our Prime Editing complex that significantly limits its potential misuse. By utilizing the ER stress response pathway, we would design our therapeutic mRNA to undergo unconventional splicing only in cells experiencing high levels of protein stress. Only this unconventional splicing would convert the mRNA into a form that can be translated into the final PE complex. This mechanism ensures that the Prime Editing complex becomes active primarily in cells under such stress conditions. While this does not exclusively limit the complex to cystic fibrosis-affected cells, it considerably narrows the range of cells where activation can occur, thus preventing arbitrary application of the editing system and reducing the risk of targeting unintended cells. 
          </p>
          <p>
          Together, these measures provide a layer of protection against dual-use risks, making it more difficult for the technology to be employed outside of its intended therapeutic context.  
          </p>
          <p>
            <H5 text="Unitended Dissemination"></H5>
          </p>
          <p>
          To minimize the risk of our construct being inadvertently released into the environment, we adhere to strict standard operating procedures (SOPs) in the laboratory. These SOPs are designed to ensure that all safety standards are maintained, particularly when handling LNPs) and genetic materials. This includes rigorous protocols for storage, disposal, and decontamination, reducing the chance of accidental dissemination of the materials we work with. 
          </p>
          <p>
          In addition to our laboratory practices, we have formulated our LNPs with specific chemical components that enable them to selectively fuse with lung epithelial cells, such as ionocytes and club cells, which express CFTR. This selective fusion ensures that even if the LNPs were to accidentally enter the environment, they would only interact with the intended cells. This approach significantly enhances the specificity of the LNPs and provides an additional layer of containment, thereby reducing the risk of unintended dissemination or environmental contamination.  
          </p>
          <p>
          Looking ahead, we plan to further enhance the specificity of our LNPs by incorporating antibodies on their surface. These antibodies would be engineered to bind exclusively to surface proteins present on CFTR-expressing lung epithelial cells, adding an extra layer of control. While this antibody-based targeting has not yet been implemented, it represents a crucial next step in our development process, reinforcing our commitment to biosecurity by limiting the potential for unintended dissemination. 
          </p>
          <p>
          Together, these practices and design strategies help to ensure that the risk of our constructs inadvertently affecting non-target organisms or environments is minimized. 
          </p>
          <p>
            <H5 text="Unauthorized Access"></H5>
          </p>
          <p>
          To prevent unauthorized access to our genetic sequences, plasmid constructs, and other sensitive information, we have implemented strict internal biosecurity policies. These policies ensure that we carefully manage which materials exist in physical form and their exact storage locations. 
          </p>
          <p>
          In terms of digital security, we strictly regulate access to our data storage systems through a combination of measures. We use a secure, password-protected cloud system, ensuring only authorized team members can access sensitive project information. Access to the lab is limited to team members with internal keys, and our server security includes stringent access rights management, allowing only approved individuals to view, modify, or share the data. These safeguards ensure that project information remains protected against unauthorized access. 
          </p>
          <p>
          Furthermore, we ensure that any sensitive data generated during our project is only published in the supplementary materials section, which is accessible exclusively to those with an official iGEM account. By taking this approach, we can limit the availability of sensitive information and reduce the risk of it being misused. 
          </p>
          <p>
            <H5 text="Synthetic Biology and Information Sharing"></H5>
          </p>
          <p>
          Managing the risks associated with synthetic biology and information sharing is a complex challenge. Many of the strategies we use to address other risks, such as "Unauthorized Access" and "Dual-Use Potential," are equally relevant in this context. For instance, our strict control over access to sensitive information and our safety mechanisms both help mitigate the risks posed by the accessibility of synthetic biology tools. 
          </p>
          <p>
          However, it is important to acknowledge that this risk is inherent to the field of synthetic biology. The ease of obtaining information and, with the right expertise, combining various components to create powerful and potentially hazardous tools is a fundamental concern. 
          </p>
          <p>
          To address this, we adhere strictly to all policies and regulations set forth by iGEM, our university, the German government, and the European Union. By aligning our practices with existing regulations on synthetic biology, we aim to conduct our work responsibly and reduce the risks associated with the field. 
          </p>
          <p>
            <H5 text="Public Perception and Miscommunication"></H5>
          </p>
          <p>
          One of the challenges in scientific research, especially in fields like synthetic biology, is that advancements can often outpace public understanding and discourse. This can lead to confusion, fear, or mistrust if the research is not communicated effectively. To address this issue, we believe that scientific progress should occur in constant dialogue with the public. 
          </p>
          <p>
          We have adopted a strong Human Practices approach to ensure transparency and foster public engagement. Our efforts include initiatives like "MUKOmoove" and "Teuto ruft," where we have worked directly with students, educational institutions, and public organizations. Through these initiatives, we aim to explain our project, discuss its implications, and answer any questions, thus maintaining an open line of communication. By collaborating with a variety of public entities, including patient associations, educational programs, and community groups, we ensure that our research remains accessible and understandable to a broader audience.  
          </p>
          <p>
          This proactive approach helps us address potential concerns, demystify our research, and contribute to a more informed public perception of synthetic biology. 
          </p>
        </Subesction>
      </Section>
      <Section title="Bioethics" id="Bioethics">
            <div>
                <p>
                    Bioethics is an interdisciplinary field of research that addresses ethical issues pertaining to the life sciences and medical research. It plays a pivotal role in contemporary research, particularly in projects that employ human samples or data. This is due to the fact that in these cases, the protection of the rights and dignity of the people involved is of the utmost importance <SupScrollLink label="1"/> (Chadwick_2012_Thiele_2001a). In order to ascertain the necessity for an ethics application, an interview was conducted with Eva-Maria Berens, the scientific director of the office of the Ethics Committee at Bielefeld University, as part of the current research project. Following a comprehensive review, it was concluded that an ethics application was not necessary for the specific research project. Nevertheless, a comprehensive patient consent form was developed in conjunction with Eva-Maria Berens to guarantee that the donors of their samples are adequately informed and provide their consent of their own volition. The document guarantees that all pertinent information regarding sample collection, utilisation and storage is provided in an intelligible format. Furthermore, an interview was conducted with Dr. Timm Weber, a representative of the biobank, to discuss the topic of bioethics in greater depth. During the course of the interviews, the ethical aspects of sample storage and utilisation within the biobank were discussed in detail. Particular attention was paid to the responsible handling and protection of the rights of the test subjects. The discussion of bioethics in both interviews emphasises the relevance of ethical principles for research and ensures that it is conducted in accordance with the highest ethical standards.
                </p>
            </div>
        <Subesction title="Gene Therapy" id="Bioethics1">
          <div>
                <p>
                The potential of gene therapy to treat genetic diseases is promising, but it is also associated with significant ethical issues. One of the principal challenges is ensuring the safety of the procedure and the potential for unforeseen long-term consequences. Such consequences may only become apparent years after the genetic intervention has taken place. The modification of the germline, which affects not only the individual but also future generations, is a particularly sensitive issue. This gives rise to the question of the extent to which the decisions made today will influence future generations without their consent, thereby jeopardising intergenerational justice <SupScrollLink label="2"/> (Rubeis_Steger_2018). Another ethical issue is the potential for misuse for eugenic purposes. While the current focus is on combating disease, future applications could be aimed at 'optimising' human traits, which could result in a worsening of social inequalities. Access to gene therapy is also a significant issue. High costs could limit access to wealthy population groups, which would reinforce existing inequalities <SupScrollLink label="3"/> (Ansah_2022_Cornetta_Patel_Wanjiku_Busakhala_2018). The issue of informed consent is also a key aspect. Many patients do not have the necessary knowledge to fully understand the complex risks, which raises ethical questions about their decision-making capacity. Overall, the debate around gene therapy highlights that ethical considerations such as safety, justice and patient rights need to be considered alongside scientific progress <SupScrollLink label="4"/> (Pugh_2020).  
                </p>
          </div>
        </Subesction>
        <Subesction title="Primary Cells" id="Bioethics2">
          <div>
            <H4 text="Introduction of primary cultures"></H4>
            <p>
            A primary culture is defined as a cell culture that is isolated directly from the tissue of an organism. In our case, the organism is human. The cells are then cultivated in a controlled environment, namely an S2 laboratory <SupScrollLink label="5"/> (Gstraunthaler_Lindl_2013). Primary cultures are a fundamental biomedical research tool, widely regarded as indispensable due to their capacity for realistic modelling of complex cell interactions. Primary cells are derived directly from the tissue of an organism and, as a consequence, they essentially retain their original properties. Consequently, they mirror the authentic conditions of the target tissue, which is vital for accurately assessing the impact of a therapeutic agent. In contrast, HEK cells represent transformed cell lines that exhibit physiological properties distinct from those of target cells in the human body. The effect of a therapeutic agent is typically limited to a specific cell type. The investigation of cell-specific effects and reactions of an active substance is feasible with the use of primary cells, as these possess the functional characteristics inherent to the cell type under consideration. Although HEK cells are relatively straightforward to cultivate, they are less representative of a number of tissue types and may activate other signalling pathways. The authenticity of the receptors and signalling pathways is guaranteed, as primary cells show the natural expression of receptors, ion channels and other cellular mechanisms. HEK cells are often genetically modified to express specific receptors, which can be useful for simple test systems. However, this does not reflect the complex environment of a real tissue. Given the sensitivity of primary cultures to environmental influences, thus resulting in higher risk of a contamination, it is imperative that researchers employ special safety measures to ensure the safety of themselves and the integrity of the cells. Primary cultures are employed extensively in the development of vaccines, cancer research and the investigation of basic cell processes. 
            </p>
            <H4 text="Ethics in work with primary cultures"></H4>
            <p>
                The term 'ethics' is used to describe the examination of moral principles that determine the behaviour of individuals or groups <SupScrollLink label="6"/> (Thiele_2001b). In a scientific context, the term 'ethics' encompasses the examination of the moral justifiability of actions and decisions, particularly with regard to the welfare of living beings and the responsible use of resources <SupScrollLink label="7"/> (Gethmann_2001). The isolation of primary cells from living organisms raises ethical questions, particularly in the case of human or animal tissue. In the context of research with animal primary cells, careful consideration must be given to the need for animal suffering and the potential benefits of the research <SupScrollLink label="8"/> (Kiani_Pheby_Henehan_Brown_Sieving_Sykora_Marks_Falsini_Capodicasa_Miertus_et al._2022). An ethical dilemma frequently arises from the fact that primary cells offer the most meaningful data from a biological standpoint, yet their production is associated with challenges. In this context, the necessity of primary cell cultures is called into question, and the promotion of alternative methods, such as artificially produced tissues or organoids, is advocated where feasible. It is of crucial importance to emphasize the necessity of ethical responsibility in the collection of primary cultures. It is of the utmost importance that the procedure is carried out with consideration for the rights, and particularly the well-being of the donor. The removal of cells or tissue must be medically justifiable and, moreover, ethically justifiable in every case. To this end, the potential for research use and the possible risks and burdens for the donor must be weighed against each other to ensure careful consideration. However, it is also particularly important to ensure that the donor is involved in the entire process and is able to make an informed decision. The purpose of the research, the use of the cells and possible consequences must also be made transparent at all times. 
                The obtaining of informed consent represents a fundamental aspect of ethical practice in the collection of primary cells. This process must encompass not only a formal consent procedure, but also the provision of comprehensive information to donors regarding the collection, utilisation and prospective future applications of the cells. The act of consent must be given freely and without undue influence, and donors must be fully aware of the consequences of their participation. Furthermore, donors must be granted the right to revoke their consent at any time without consequence. Prior to the collection of cells, a comprehensive discussion is held with the donor, during which all pertinent details are elucidated and any queries or concerns they may have, are addressed. This guarantees that the donor is adequately informed and is thus able to make an autonomous decision based on a comprehensive understanding of the procedure. 
                The protection of privacy and confidentiality is of paramount importance when working with primary cultures. Given that primary cultures are predominantly human tissue, they contain genetic information and other personal data that is sensitive and deserving of protection. It is therefore of great importance that the data is anonymized and kept strictly confidential in order to protect the identity of the donor. 
                Every person who has access to the data or samples must be obliged to comply with confidentiality standards. It must be ensured that all legal requirements for data protection are met, including compliance with data protection laws such as the GDPR in the EU. 
            </p>
            <H4 text="Safety aspects when working with primary cultures "></H4>
            <p>
            When working with primary cultures, there is a risk that the cells may be potentially infectious samples or contaminated. Therefore, it is of the utmost importance to adhere to strict biological safety measures in order to minimize the risk of exposure to dangerous pathogens. This includes the use of personal protective equipment, working in a biosafety cabinet and adhering to decontamination protocols.
            The overarching objective is the safeguarding of laboratory staff. This is achieved through the utilization of personal protective equipment, encompassing gloves, lab coats and safety goggles, in addition to the provision of training in pertinent safety protocols. 
            In order to prevent the release of potentially hazardous material, it is imperative that biological waste is disposed of in accordance with the established regulatory framework. The waste is subjected to rigorous sterilisation by autoclaving and subsequently rendered safe for disposal in the designated and labelled containers. 
            </p>
            <H4 text="Regulatory framework"></H4>
            <p>
            The field of primary culture research is subject to a plethora of legal regulations and guidelines at both the national and international levels. These regulations dictate the manner in which primary cultures may be obtained, used, and disposed of. They encompass regulations pertaining to the protection of donors, the secure handling of biological material, and the ethical responsibility towards the cells and their origin. It is of paramount importance that all laboratory practices align with these regulations. 
            </p>
          </div>
        </Subesction>
        <Subesction title="Consent and Guidelines" id="Bioethics3">
          <LoremMedium/>
        </Subesction>
      </Section>
      <Section title="References" id="References">
                <ol>
                    {/* <!-- Citation num 1--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                    <span property="schema:author" typeof="schema:Person">
                    <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 2--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 3--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 4--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 5--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 6--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                     {/* <!-- Citation num 7--> */}
                     <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                    {/* <!-- Citation num 8--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                {/* <!-- Citation num 9--> */}
                <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                    {/* <!-- Citation num 10--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>
                </ol>
                </Section>
    </>
  );
}
